'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _reactTestRenderer = require('react-test-renderer');

var _reactTestRenderer2 = _interopRequireDefault(_reactTestRenderer);

var _avatarContent = require('./../avatarContent');

var _avatarContent2 = _interopRequireDefault(_avatarContent);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<AvatarContent/>', function () {
    it('should render an img when src is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_avatarContent2.default, { iconName: 'standard:user', src: 'images/avatar1.jpg' }));
        expect(component.find('img').exists()).toBe(true);
    });
    it('should pass right props to the img element when a valid src is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_avatarContent2.default, { iconName: 'standard:user', src: 'images/avatar1.jpg', title: 'Title' }));
        expect(component.find('img').props()).toEqual({
            src: 'images/avatar1.jpg',
            onError: expect.any(Function),
            title: 'Title'
        });
    });
    it('should render an abbr when src is not passed and initials props is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_avatarContent2.default, { iconName: 'standard:user', initials: 'JD' }));
        expect(component.find('abbr').exists()).toBe(true);
    });
    it('should pass right props to the abbr element when src is not passed and initials props is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_avatarContent2.default, { iconName: 'standard:user', initialsVariant: 'default', initials: 'JD', title: 'Title' }));
        expect(component.find('abbr').props()).toEqual({
            children: 'JD',
            className: 'slds-avatar__initials slds-icon-standard-user',
            title: 'Title'
        });
    });
    it('should render an Icon when src and initials are not passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_avatarContent2.default, { iconName: 'standard:user' }));
        expect(component.find('Icon').exists()).toBe(true);
    });
    it('should pass right props to Icon component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_avatarContent2.default, { iconName: 'standard:user', title: 'Title' }));
        expect(component.find('Icon').props()).toEqual(expect.objectContaining({
            iconName: 'standard:user',
            title: 'Title'
        }));
    });
    it('should pass standard:user as iconName when the sprite of the iconName passed is not standard', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_avatarContent2.default, { iconName: 'utility:user', title: 'Title' }));
        expect(component.find('Icon').props()).toEqual(expect.objectContaining({
            iconName: 'standard:user',
            title: 'Title'
        }));
    });
    it('should have the right class names when initials variant is default', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_avatarContent2.default, { iconName: 'standard:user', initialsVariant: 'default', initials: 'JD' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when initials variant is inverse', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_avatarContent2.default, { iconName: 'standard:user', initials: 'JD', initialsVariant: 'inverse' }));
        expect(component).toMatchSnapshot();
    });
});