'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = Badge;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _iconNamePropType = require('./../../propTypes/iconNamePropType');

var _iconNamePropType2 = _interopRequireDefault(_iconNamePropType);

var _badgeIcon = require('./badgeIcon');

var _badgeIcon2 = _interopRequireDefault(_badgeIcon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Badges are labels which hold small amounts of information.
 */
function Badge(props) {
    var className = props.className,
        style = props.style,
        label = props.label,
        variant = props.variant,
        iconName = props.iconName,
        iconPosition = props.iconPosition;


    function getClassName() {
        return (0, _classnames2.default)('slds-align_absolute-center', 'slds-badge', 'slds-badge_' + variant, className);
    }

    var showLeftIcon = !!(iconName && iconPosition === 'left');
    var showRightIcon = !!(iconName && iconPosition === 'right');

    return _react2.default.createElement(
        'span',
        { className: getClassName(), style: style },
        _react2.default.createElement(_badgeIcon2.default, {
            'data-id': 'left-icon',
            iconName: iconName,
            iconPosition: iconPosition,
            label: label,
            isVisible: showLeftIcon }),
        label,
        _react2.default.createElement(_badgeIcon2.default, {
            'data-id': 'right-icon',
            iconName: iconName,
            iconPosition: iconPosition,
            label: label,
            isVisible: showRightIcon })
    );
}

Badge.propTypes = {
    /** The text to be displayed inside the badge. */
    label: _propTypes2.default.node,
    /** The Lightning Design System name of the icon used as a fallback when
    * the image fails to load. Names are written in the format {sprite_name}:{icon_name}
    * where {sprite_name} is the category, and {icon_name} is the specific icon to be displayed.
    * Only utility icons can be used in this component. */
    iconName: _iconNamePropType2.default.oneOf(['utility']),
    /** Describes the position of the icon with respect to body. Options include left and right.
    * This value defaults to left. */
    iconPosition: _propTypes2.default.oneOf(['left', 'right']),
    /** The variant changes the appearance of the badge. Accepted variants include base,
    * default, inverse and lightest. This value defaults to default. */
    variant: _propTypes2.default.oneOf(['default', 'inverse', 'lightest']),
    /** A CSS class for the outer element, in addition to the component's base classes. */
    className: _propTypes2.default.string,
    /** An object with custom style applied to the outer element. */
    style: _propTypes2.default.object
};

Badge.defaultProps = {
    label: null,
    iconName: '',
    iconPosition: 'left',
    variant: 'default',
    className: undefined,
    style: undefined
};