'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _reactTestRenderer = require('react-test-renderer');

var _reactTestRenderer2 = _interopRequireDefault(_reactTestRenderer);

var _index = require('./../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Button/>', function () {
    it('should call onClick function when someone click over', function () {
        var onClickMockFn = jest.fn();
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'Button label', onClick: onClickMockFn }));

        component.simulate('click');
        expect(onClickMockFn.mock.calls.length).toBe(1);
    });
    it('should call onBlur function when it lost the focus', function () {
        var onBlurMockFn = jest.fn();
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'Button label', onBlur: onBlurMockFn }));

        component.simulate('blur');
        expect(onBlurMockFn.mock.calls.length).toBe(1);
    });
    it('should call onFocus function when it gets the focus', function () {
        var onFocusMockFn = jest.fn();
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'Button label', onFocus: onFocusMockFn }));

        component.simulate('focus');
        expect(onFocusMockFn.mock.calls.length).toBe(1);
    });
    it('should be defined the click method', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));

        expect(_typeof(component.instance().click)).toBe('function');
    });
    it('should be defined the focus method', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));

        expect(_typeof(component.instance().focus)).toBe('function');
    });
    it('should be defined the blur method', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));

        expect(_typeof(component.instance().blur)).toBe('function');
    });
    it('should focus the button when the focus method is called', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));

        component.instance().focus();
        var focusedElementDataId = document.activeElement.getAttribute('data-id');
        var buttonDataId = component.find('button').prop('data-id');
        expect(focusedElementDataId).toBe(buttonDataId);
    });
    it('should blur the button when the blur method is called', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));
        var instance = component.instance();
        var buttonDataId = component.find('button').prop('data-id');

        instance.focus();
        expect(document.activeElement.getAttribute('data-id')).toBe(buttonDataId);
        instance.blur();
        expect(document.activeElement.getAttribute('data-id')).toBeNull();
    });
    it('should set disable to true when it is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'my label', disabled: true }));

        expect(component.find('button').prop('disabled')).toBe(true);
    });
    it('should set the tabIndex passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'my label', tabIndex: 0 }));

        expect(component.find('button').prop('tabIndex')).toBe(0);
    });
    it('should set the title passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'my label', title: 'my title' }));

        expect(component.find('button').prop('title')).toBe('my title');
    });
    it('should set the type passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'my label', type: 'reset' }));

        expect(component.find('button').prop('type')).toBe('reset');
    });
    it('should set aria-haspopup to true when it is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'my label', ariaHaspopup: true }));

        expect(component.find('button').prop('aria-haspopup')).toBe(true);
    });
    it('should set the label passed as children', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'Click me' }));

        expect(component.find('button').text()).toBe('Click me');
    });
    it('should have the right class names', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { label: 'Button Label' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant neutral and have a custom class', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { label: 'Button Label', variant: 'neutral', className: 'my-custom-class-name' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant brand', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { label: 'Button Label', variant: 'brand' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant outline-brand', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { label: 'Button Label', variant: 'outline-brand' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant destructive', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { label: 'Button Label', variant: 'destructive' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant success', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { label: 'Button Label', variant: 'success' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant inverse', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { label: 'Button Label', variant: 'inverse' }));
        expect(component).toMatchSnapshot();
    });
    it('should render an icon on the left when iconName is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'Button Label', iconName: 'utility:world' }));
        var leftIcon = component.find('[data-id="left-icon"]');
        var rightIcon = component.find('[data-id="right-icon"]');

        expect(leftIcon.prop('isVisible')).toBe(true);
        expect(rightIcon.prop('isVisible')).toBe(false);
    });
    it('should render an icon on the right when iconName is passed and iconPosition is right', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { label: 'Button Label', iconName: 'utility:world', iconPosition: 'right' }));
        var leftIcon = component.find('[data-id="left-icon"]');
        var rightIcon = component.find('[data-id="right-icon"]');

        expect(leftIcon.prop('isVisible')).toBe(false);
        expect(rightIcon.prop('isVisible')).toBe(true);
    });
});