'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _iconNamePropType = require('./../../propTypes/iconNamePropType');

var _iconNamePropType2 = _interopRequireDefault(_iconNamePropType);

var _icon = require('./icon');

var _icon2 = _interopRequireDefault(_icon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
* Buttons are clickable items used to perform an action.
*/
var Button = function (_Component) {
    _inherits(Button, _Component);

    function Button(props) {
        _classCallCheck(this, Button);

        var _this = _possibleConstructorReturn(this, (Button.__proto__ || Object.getPrototypeOf(Button)).call(this, props));

        _this.buttonRef = _react2.default.createRef();
        _this.click = _this.click.bind(_this);
        _this.focus = _this.focus.bind(_this);
        _this.blur = _this.blur.bind(_this);
        return _this;
    }

    _createClass(Button, [{
        key: 'getClassNames',
        value: function getClassNames() {
            var _props = this.props,
                className = _props.className,
                variant = _props.variant;

            return (0, _classnames2.default)('slds-grid', 'slds-grid_align-center', 'slds-media_center', 'slds-button', 'slds-button_' + variant, className);
        }

        /**
        * Sets focus on the element.
        * @public
        */

    }, {
        key: 'focus',
        value: function focus() {
            this.buttonRef.current.focus();
        }

        /**
        * Sets click on the element.
        * @public
        */

    }, {
        key: 'click',
        value: function click() {
            this.buttonRef.current.click();
        }

        /**
        * Sets blur on the element.
        * @public
        */

    }, {
        key: 'blur',
        value: function blur() {
            this.buttonRef.current.blur();
        }
    }, {
        key: 'render',
        value: function render() {
            var _props2 = this.props,
                style = _props2.style,
                label = _props2.label,
                disabled = _props2.disabled,
                tabIndex = _props2.tabIndex,
                onFocus = _props2.onFocus,
                onBlur = _props2.onBlur,
                onClick = _props2.onClick,
                title = _props2.title,
                type = _props2.type,
                ariaHaspopup = _props2.ariaHaspopup,
                iconName = _props2.iconName,
                iconPosition = _props2.iconPosition;


            var showLeftIcon = !!(iconName && iconPosition === 'left');
            var showRightIcon = !!(iconName && iconPosition === 'right');

            return _react2.default.createElement(
                'button',
                {
                    'data-id': 'button-element',
                    className: this.getClassNames(),
                    style: style,
                    disabled: disabled,
                    tabIndex: tabIndex,
                    onFocus: onFocus,
                    onBlur: onBlur,
                    onClick: onClick,
                    title: title,
                    type: type,
                    'aria-haspopup': ariaHaspopup,
                    ref: this.buttonRef },
                _react2.default.createElement(_icon2.default, {
                    'data-id': 'left-icon',
                    iconName: iconName,
                    position: iconPosition,
                    isVisible: showLeftIcon }),
                label,
                _react2.default.createElement(_icon2.default, {
                    'data-id': 'right-icon',
                    iconName: iconName,
                    position: iconPosition,
                    isVisible: showRightIcon })
            );
        }
    }]);

    return Button;
}(_react.Component);

exports.default = Button;


Button.propTypes = {
    /** The text to be displayed inside the button. */
    label: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.node]).isRequired,
    /** The variant changes the appearance of the button.
    * Accepted variants include base, neutral, brand, outline-brand, destructive,
    * success and inverse. This value defaults to base. */
    variant: _propTypes2.default.oneOf(['base', 'neutral', 'brand', 'outline-brand', 'destructive', 'success', 'inverse']),
    /** The Lightning Design System name of the icon used as a fallback when
    * the image fails to load. Names are written in the format {sprite_name}:{icon_name}
    * where {sprite_name} is the category, and {icon_name} is the specific icon to be displayed.
    * Only utility icons can be used in this component. */
    iconName: _iconNamePropType2.default.oneOf(['utility']),
    /** Describes the position of the icon with respect to body. Options include left and right.
    * This value defaults to left. */
    iconPosition: _propTypes2.default.oneOf(['left', 'right']),
    /** Displays tooltip text when the mouse moves over the element. */
    title: _propTypes2.default.string,
    /** Specifies the type of button. Valid values are button, reset, and submit.
    * This value defaults to button. */
    type: _propTypes2.default.oneOf(['button', 'submit', 'reset']),
    /** Specifies whether this button should be displayed in a disabled state.
    * Disabled buttons can't be clicked. This value defaults to false. */
    disabled: _propTypes2.default.bool,
    /** Specifies the tab order of an element (when the tab button is used for navigating). */
    tabIndex: _propTypes2.default.number,
    /** The action triggered when the button is clicked. */
    onClick: _propTypes2.default.func,
    /** The action triggered when the element receives focus. */
    onFocus: _propTypes2.default.func,
    /** The action triggered when the element releases focus. */
    onBlur: _propTypes2.default.func,
    /** Indicates that the element has a popup context menu or sub-level menu. */
    ariaHaspopup: _propTypes2.default.bool,
    /** A CSS class for the outer element, in addition to the component's base classes. */
    className: _propTypes2.default.string,
    /** An object with custom style applied to the outer element. */
    style: _propTypes2.default.object
};

Button.defaultProps = {
    variant: 'base',
    iconName: '',
    iconPosition: 'left',
    title: undefined,
    type: 'button',
    disabled: false,
    tabIndex: undefined,
    onClick: function onClick() {},
    onFocus: function onFocus() {},
    onBlur: function onBlur() {},
    ariaHaspopup: false,
    className: undefined,
    style: undefined
};