'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _reactTestRenderer = require('react-test-renderer');

var _reactTestRenderer2 = _interopRequireDefault(_reactTestRenderer);

var _index = require('./../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<ButtonIcon/>', function () {
    it('should focus the button when the focus method is called', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));

        component.instance().focus();
        var focusedElementDataId = document.activeElement.getAttribute('data-id');
        var buttonDataId = component.find('button').prop('data-id');
        expect(focusedElementDataId).toBe(buttonDataId);
    });
    it('should blur the button when the blur method is called', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));
        var instance = component.instance();
        var buttonDataId = component.find('button').prop('data-id');

        instance.focus();
        expect(document.activeElement.getAttribute('data-id')).toBe(buttonDataId);
        instance.blur();
        expect(document.activeElement.getAttribute('data-id')).toBeNull();
    });
    it('should set disable to true when it is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { disabled: true }));

        expect(component.find('button').prop('disabled')).toBe(true);
    });
    it('should set the tabIndex passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { tabIndex: 0 }));

        expect(component.find('button').prop('tabIndex')).toBe(0);
    });
    it('should set the title passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { title: 'my title' }));

        expect(component.find('button').prop('title')).toBe('my title');
    });
    it('should set the type passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { type: 'reset' }));

        expect(component.find('button').prop('type')).toBe('reset');
    });
    it('should set aria-haspopup to true when it is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { ariaHaspopup: true }));

        expect(component.find('button').prop('aria-haspopup')).toBe(true);
    });
    it('should pass assistiveText to the prop text of AssistiveText component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { assistiveText: 'for screen readers' }));
        expect(component.find('AssistiveText').prop('text')).toBe('for screen readers');
    });
    it('should have the right class names', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, null));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is border-filled and have a custom class', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { variant: 'border-filled', className: 'my-custom-class-name' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is border-inverse and size is small', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { variant: 'border-inverse', size: 'small' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is border and size is x-small', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { variant: 'border', size: 'x-small' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is brand and size is xx-small', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { variant: 'brand', size: 'xx-small' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is inverse and size is large', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { variant: 'inverse', size: 'large' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is container', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { variant: 'container' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is base and size is xx-small', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { iconName: 'utility:activity', size: 'xx-small' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is base and size is x-small', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { iconName: 'utility:activity', size: 'x-small' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is base and size is small', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { iconName: 'utility:activity', size: 'small' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is base and size is medium', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { iconName: 'utility:activity', size: 'medium' }));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when variant is base and size is large', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_index2.default, { iconName: 'utility:activity', size: 'large' }));
        expect(component).toMatchSnapshot();
    });
});