'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactTestRenderer = require('react-test-renderer');

var _reactTestRenderer2 = _interopRequireDefault(_reactTestRenderer);

var _enzyme = require('enzyme');

var _ = require('./../');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<ButtonMenu/>', function () {
    it('should focus the button when the focus method is called', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));

        component.instance().focus();
        var focusedElementDataId = document.activeElement.getAttribute('data-id');
        var buttonDataId = component.find('button').prop('data-id');
        expect(focusedElementDataId).toBe(buttonDataId);
    });
    it('should blur the button when the blur method is called', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        var instance = component.instance();
        var buttonDataId = component.find('button').prop('data-id');

        instance.focus();
        expect(document.activeElement.getAttribute('data-id')).toBe(buttonDataId);
        instance.blur();
        expect(document.activeElement.getAttribute('data-id')).toBeNull();
    });
    it('should set the title passed in the ButtonIcon', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { title: 'my title' },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ButtonIcon').prop('title')).toBe('my title');
    });
    it('should set the assistiveText passed in the ButtonIcon', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { assistiveText: 'assistive description' },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ButtonIcon').prop('assistiveText')).toBe('assistive description');
    });
    it('should set the iconName passed in the ButtonIcon', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { iconName: 'utility:user' },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ButtonIcon').prop('iconName')).toBe('utility:user');
    });
    it('should set the buttonVariant passed as variant in the ButtonIcon', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { buttonVariant: 'brand' },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ButtonIcon').prop('variant')).toBe('brand');
    });
    it('should set the buttonSize passed as size in the ButtonIcon', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { buttonSize: 'large' },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ButtonIcon').prop('size')).toBe('large');
    });
    it('should set the disabled passed in the ButtonIcon', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { disabled: true },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ButtonIcon').prop('disabled')).toBe(true);
    });
    it('should set the tabIndex passed in the ButtonIcon', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { tabIndex: 0 },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ButtonIcon').prop('tabIndex')).toBe(0);
    });
    it('should set the isLoading passed in the MenuContent', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { isLoading: true },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('MenuContent').prop('isLoading')).toBe(true);
    });
    it('should render the children passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            null,
            _react2.default.createElement(
                'span',
                { 'data-id': 'menu-children' },
                'menu content'
            )
        ));
        expect(component.find('span[data-id="menu-children"]').text()).toBe('menu content');
    });
    it('should set the role as menu in the ul element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            null,
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ul').prop('role')).toBe('menu');
    });
    it('should set the title passed as the aria-label in the ul element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { title: 'button title', assistiveText: 'assistive description' },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ul').prop('aria-label')).toBe('button title');
    });
    it('should set the assistiveText passed as the aria-label in the ul element when the title is not passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            { assistiveText: 'assistive description' },
            _react2.default.createElement('span', null)
        ));
        expect(component.find('ul').prop('aria-label')).toBe('assistive description');
    });
    it('should set the right class names to the container element when the menu is opened', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            null,
            _react2.default.createElement('span', null)
        ));
        component.find('ButtonIcon').simulate('click');
        expect(component.find('div[role="presentation"]').prop('className')).toBe('slds-dropdown-trigger slds-dropdown-trigger_click slds-button_last slds-is-open');
    });
    it('should have the right class names', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(
            _2.default,
            null,
            _react2.default.createElement('span', null)
        ));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when menuAlignment is left and isLoading is true', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(
            _2.default,
            { menuAlignment: 'left', isLoading: true },
            _react2.default.createElement('span', null)
        ));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when menuAlignment is right and menuSize is xx-small', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(
            _2.default,
            { menuAlignment: 'right', menuSize: 'xx-small' },
            _react2.default.createElement('span', null)
        ));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when menuSize is x-small', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(
            _2.default,
            { menuSize: 'x-small' },
            _react2.default.createElement('span', null)
        ));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when menuSize is small', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(
            _2.default,
            { menuSize: 'small' },
            _react2.default.createElement('span', null)
        ));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when menuSize is medium', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(
            _2.default,
            { menuSize: 'medium' },
            _react2.default.createElement('span', null)
        ));
        expect(component).toMatchSnapshot();
    });
    it('should have the right class names when menuSize is large', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(
            _2.default,
            { menuSize: 'large' },
            _react2.default.createElement('span', null)
        ));
        expect(component).toMatchSnapshot();
    });
});