'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = Card;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _iconNamePropType = require('./../../propTypes/iconNamePropType');

var _iconNamePropType2 = _interopRequireDefault(_iconNamePropType);

var _headerIcon = require('./headerIcon');

var _headerIcon2 = _interopRequireDefault(_headerIcon);

var _headerTitle = require('./headerTitle');

var _headerTitle2 = _interopRequireDefault(_headerTitle);

var _cardBody = require('./cardBody');

var _cardBody2 = _interopRequireDefault(_cardBody);

var _footer = require('./footer');

var _footer2 = _interopRequireDefault(_footer);

var _actions = require('./actions');

var _actions2 = _interopRequireDefault(_actions);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
* Cards are used to apply a container around a
* related grouping of information.
*/
function Card(props) {
    var className = props.className,
        style = props.style,
        actions = props.actions,
        children = props.children,
        footer = props.footer,
        iconName = props.iconName,
        title = props.title,
        isLoading = props.isLoading;


    var getContainerClassName = function getContainerClassName() {
        return (0, _classnames2.default)('slds-card', className);
    };

    return _react2.default.createElement(
        'article',
        { className: getContainerClassName(), style: style },
        _react2.default.createElement(
            'div',
            { className: 'slds-card__header slds-grid' },
            _react2.default.createElement(
                'header',
                { className: 'slds-media slds-media_center slds-has-flexi-truncate' },
                _react2.default.createElement(_headerIcon2.default, { iconName: iconName }),
                _react2.default.createElement(_headerTitle2.default, { title: title })
            ),
            _react2.default.createElement(_actions2.default, { content: actions })
        ),
        _react2.default.createElement(
            'div',
            { className: 'slds-card__body slds-card__body_inner' },
            _react2.default.createElement(
                _cardBody2.default,
                { isLoading: isLoading },
                children
            )
        ),
        _react2.default.createElement(_footer2.default, { content: footer, isLoading: isLoading })
    );
}

Card.propTypes = {
    /** The title can include text or another component, and is displayed in the header. */
    title: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.node]).isRequired,
    /** The Lightning Design System name of the icon used as a fallback when
    * the image fails to load. Names are written in the format {sprite_name}:{icon_name}
    * where {sprite_name} is the category, and {icon_name} is the specific icon to be displayed.
    * The icon is displayed in the header to the left of the title. */
    iconName: _iconNamePropType2.default.simple,
    /** Actions are components such as button or buttonIcon. Actions are displayed in the header. */
    actions: _propTypes2.default.node,
    /** The footer can include text or another component. */
    footer: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.node]),
    /** If is set to true, then is showed a loading symbol. */
    isLoading: _propTypes2.default.bool,
    /** A CSS class for the outer element, in addition to the component's base classes. */
    className: _propTypes2.default.string,
    /** An object with custom style applied to the outer element. */
    style: _propTypes2.default.object,
    /**
    * This prop that should not be visible in the documentation.
    * @ignore
    */
    children: _propTypes2.default.node
};

Card.defaultProps = {
    iconName: undefined,
    actions: null,
    footer: null,
    isLoading: false,
    className: undefined,
    style: undefined,
    children: null
};