'use strict';

var _utils = require('./../utils');

describe('Icon utils', function () {
    describe('isUtilitySprite', function () {
        it('should return true if the icon sprite is utility', function () {
            expect((0, _utils.isUtilitySprite)('utility:add_contact')).toBe(true);
        });
        it('should return false if the icon sprite is other than utility', function () {
            expect((0, _utils.isUtilitySprite)('custom:custom23')).toBe(false);
        });
    });
    describe('isActionSprite', function () {
        it('should return true if the icon sprite is action', function () {
            expect((0, _utils.isActionSprite)('action:add_contact')).toBe(true);
        });
        it('should return false if the icon sprite is other than action', function () {
            expect((0, _utils.isActionSprite)('custom:custom23')).toBe(false);
        });
    });
    describe('isCustomSprite', function () {
        it('should return true if the icon sprite is custom', function () {
            expect((0, _utils.isCustomSprite)('custom:custom1')).toBe(true);
        });
        it('should return false if the icon sprite is other than custom', function () {
            expect((0, _utils.isCustomSprite)('utility:announcement')).toBe(false);
        });
    });
    describe('isStandardSprite', function () {
        it('should return true if the icon sprite is standard', function () {
            expect((0, _utils.isStandardSprite)('standard:bot')).toBe(true);
        });
        it('should return false if the icon sprite is other than standard', function () {
            expect((0, _utils.isStandardSprite)('action:log_a_call')).toBe(false);
        });
    });
    describe('normalizeIconName', function () {
        it('should normalize the iconName', function () {
            expect((0, _utils.normalizeIconName)('action:add_photo_video')).toBe('action-add-photo-video');
        });
    });
    describe('hasBackgroundColor', function () {
        it('should return true if the icon sprite is action', function () {
            expect((0, _utils.hasBackgroundColor)('action:add_contact')).toBe(true);
        });
        it('should return true if the icon sprite is custom', function () {
            expect((0, _utils.hasBackgroundColor)('custom:custom26')).toBe(true);
        });
        it('should return true if the icon sprite is standard', function () {
            expect((0, _utils.hasBackgroundColor)('standard:account')).toBe(true);
        });
        it('should return false if the icon sprite is utility', function () {
            expect((0, _utils.hasBackgroundColor)('utility:adduser')).toBe(false);
        });
        it('should return false if the icon sprite is doctype', function () {
            expect((0, _utils.hasBackgroundColor)('doctype:html')).toBe(false);
        });
    });
});