'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = Icon;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames3 = require('classnames');

var _classnames4 = _interopRequireDefault(_classnames3);

var _iconNamePropType = require('./../../propTypes/iconNamePropType');

var _iconNamePropType2 = _interopRequireDefault(_iconNamePropType);

var _IconSvg = require('./../IconSvg');

var _IconSvg2 = _interopRequireDefault(_IconSvg);

var _AssistiveText = require('./../AssistiveText');

var _AssistiveText2 = _interopRequireDefault(_AssistiveText);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
* The Icon component is the Lightning Design System Icon
* component and should be used for naked icons.
*/
function Icon(props) {
    var className = props.className,
        svgClassName = props.svgClassName,
        style = props.style,
        svgStyle = props.svgStyle,
        iconName = props.iconName,
        title = props.title,
        assistiveText = props.assistiveText,
        size = props.size,
        variant = props.variant;


    var getContainerClassNames = function getContainerClassNames() {
        var icon = (0, _utils.normalizeIconName)(iconName);
        var iconBackgroundColorClassName = 'slds-icon-' + icon;

        return (0, _classnames4.default)('slds-icon_container', _defineProperty({
            'slds-icon_container_circle': (0, _utils.isActionSprite)(iconName)
        }, iconBackgroundColorClassName, (0, _utils.hasBackgroundColor)(iconName)), className);
    };

    var getSvgSizeClassName = function getSvgSizeClassName() {
        var isMediumSize = size === 'medium';
        var isXSmall = size === 'x-small' || size === 'xx-small';
        if (isMediumSize) {
            return '';
        }
        if ((0, _utils.hasBackgroundColor)(iconName) && isXSmall) {
            return 'slds-icon_small';
        }
        return 'slds-icon_' + size;
    };

    var getSvgClassNames = function getSvgClassNames() {
        return (0, _classnames4.default)('slds-icon', getSvgSizeClassName(), _defineProperty({}, 'slds-icon-text-' + variant, (0, _utils.isUtilitySprite)(iconName)), svgClassName);
    };

    return _react2.default.createElement(
        'span',
        { className: getContainerClassNames(), title: title, style: style },
        _react2.default.createElement(_IconSvg2.default, { className: getSvgClassNames(), style: svgStyle, iconName: iconName }),
        _react2.default.createElement(_AssistiveText2.default, { text: assistiveText })
    );
}

Icon.propTypes = {
    /** The Lightning Design System name of the icon used as a fallback when
    * the image fails to load. Names are written in the format {sprite_name}:{icon_name}
    * where {sprite_name} is the category, and {icon_name} is the specific icon to be displayed.
    * The icon is displayed in the header to the left of the title. */
    iconName: _iconNamePropType2.default.simple.isRequired,
    /** The size of the icon. Options include xx-small, x-small, small, medium, or large.
    * This value defaults to medium. */
    size: _propTypes2.default.oneOf(['xx-small', 'x-small', 'small', 'medium', 'large']),
    /** The variant changes the appearance of a utility icon.
    * Accepted variants include default, light, warning, and error.
    * Use the light variant to implement a white fill in utility icons on dark backgrounds. */
    variant: _propTypes2.default.oneOf(['default', 'light', 'error', 'warning']),
    /** Displays tooltip text when the mouse moves over the element. */
    title: _propTypes2.default.string,
    /** A description for assistive sreen readers. */
    assistiveText: _propTypes2.default.string,
    /** It is an object with custom style applied to the svg element. */
    svgStyle: _propTypes2.default.object,
    /** A CSS class for the outer element, in addition to the component's base classes. */
    className: _propTypes2.default.string,
    /** A CSS class for the  svg element. */
    svgClassName: _propTypes2.default.string,
    /** An object with custom style applied to the outer element. */
    style: _propTypes2.default.object
};

Icon.defaultProps = {
    className: undefined,
    svgClassName: undefined,
    style: undefined,
    svgStyle: undefined,
    title: undefined,
    assistiveText: undefined,
    size: 'medium',
    variant: 'default'
};