'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _index = require('./../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Input/>', function () {
    it('should set an id in the input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));
        expect(component.find('input').prop('id')).toMatch(/input/);
    });
    it('should set the type passed in the input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { type: 'color' }));
        expect(component.find('input').prop('type')).toBe('color');
    });
    it('should set the value passed in the input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { value: 'Input value' }));
        expect(component.find('input').prop('value')).toBe('Input value');
    });
    it('should set the placeholder passed in the input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { placeholder: 'Placeholder Text' }));
        expect(component.find('input').prop('placeholder')).toBe('Placeholder Text');
    });
    it('should fire an event when the user change the input', function () {
        var onChangeFn = jest.fn();
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { onChange: onChangeFn }));
        component.find('input').simulate('change');
        expect(onChangeFn).toHaveBeenCalledTimes(1);
    });
    it('should set the tabIndex passed in the input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { tabIndex: 0 }));
        expect(component.find('input').prop('tabIndex')).toBe(0);
    });
    it('should set the disabled passed in the input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { disabled: true }));
        expect(component.find('input').prop('disabled')).toBe(true);
    });
    it('should set the readonly passed in the input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { readOnly: true }));
        expect(component.find('input').prop('readOnly')).toBe(true);
    });
    it('should set required in the input element if it is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { required: true }));
        expect(component.find('input').prop('required')).toBe(true);
    });
    it('should set required in the input element if has error', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { error: 'invalid name' }));
        expect(component.find('input').prop('required')).toBe(true);
    });
    it('should set the maxLength passed in the Input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { maxLength: 0 }));
        expect(component.find('input').prop('maxLength')).toBe(0);
    });
    it('should set the minLength passed in the Input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { minLength: 0 }));
        expect(component.find('input').prop('minLength')).toBe(0);
    });
    it('should set the pattern passed in the Input element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { pattern: 'Input Pattern' }));
        expect(component.find('input').prop('pattern')).toBe('Input Pattern');
    });
    it('should pass a generated id to the Label component and set the same id to the aria-labelledby for the input when a bottomHelpText is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { bottomHelpText: 'Help text' }));
        expect(component.find('Label').prop('id')).toMatch(/inline-text-label/);
        expect(component.find('input').prop('aria-labelledby')).toMatch(/inline-text-label/);
    });
    it('should pass a generated id to the Error component and set the same id to the aria-describedby for the input when a error is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { error: 'error message' }));
        expect(component.find('Error').prop('id')).toMatch(/error-message/);
        expect(component.find('input').prop('aria-describedby')).toMatch(/error-message/);
    });
    it('should set the bottomHelpText passed as the text prop in the Help component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { bottomHelpText: 'Help text' }));
        expect(component.find('Help').prop('text')).toBe('Help text');
    });
    it('should set the error passed in the Error component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { error: 'Error text' }));
        expect(component.find('Error').prop('error')).toBe('Error text');
    });
    it('should pass the right props to the Label component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { labelClassName: 'my-class-name', label: 'custom label', required: true }));
        expect(component.find('Label').props()).toEqual({
            className: 'my-class-name',
            label: 'custom label',
            required: true,
            inputId: expect.any(String)
        });
    });
    it('should set required in the Label component if has error', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { error: 'invalid name' }));
        expect(component.find('Label').prop('required')).toBe(true);
    });
    it('should pass the right props to the Icon component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { iconName: 'utility:activity', iconPosition: 'right', error: 'error to show' }));
        expect(component.find('Icon').props()).toEqual({
            error: 'error to show',
            iconName: 'utility:activity',
            position: 'right'
        });
    });
    it('should have the right class name in the container element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));
        expect(component.find('div[className="slds-form-element"]').exists()).toBe(true);
    });
    it('should have the right class name in the form element control container', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, null));
        expect(component.find('div[className="slds-form-element__control"]').exists()).toBe(true);
    });
    it('should have the right class names when iconName is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { iconName: 'utility:activity' }));
        expect(component.find('div[className="slds-form-element__control slds-input-has-icon slds-input-has-icon_left"]').exists()).toBe(true);
    });
    it('should have the right class names when iconName is passed and iconPosition is right', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { iconName: 'utility:activity', iconPosition: 'right' }));
        expect(component.find('div[className="slds-form-element__control slds-input-has-icon slds-input-has-icon_right"]').exists()).toBe(true);
    });
    it('should have the right class names when error is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { error: 'Error text' }));
        expect(component.find('div[className="slds-form-element slds-has-error"]').exists()).toBe(true);
    });
    it('should have the right class names when isBare', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { isBare: true }));
        expect(component.find('input').prop('className')).toBe('slds-input slds-input_bare');
    });
    it('should have the right class names when isCentered', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_index2.default, { isCentered: true }));
        expect(component.find('input').prop('className')).toBe('slds-input slds-input_counter');
    });
});