'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _ = require('./../');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<VerticalItem/>', function () {
    it('should pass the right props to li container', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { label: 'item 1', name: 'item1' }));
        expect(component.find('li').props()).toEqual(expect.objectContaining({
            className: 'slds-nav-vertical__item',
            role: 'presentation',
            onClick: expect.any(Function)
        }));
    });
    it('should set the slds-is-active className to li container when the item is selected', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { label: 'item 1', name: 'item1', selectedItem: 'item1' }));
        expect(component.find('li').prop('className')).toBe('slds-nav-vertical__item slds-is-active');
    });
    it('should pass the right props to anchor element', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { label: 'item 1', name: 'item1', href: '/page/to/go' }));
        expect(component.find('a').props()).toEqual(expect.objectContaining({
            href: '/page/to/go',
            className: 'slds-nav-vertical__action',
            'aria-current': undefined
        }));
    });
    it('should set the aria-current as page in anchor element when the item is selected', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { label: 'item 1', name: 'item1', selectedItem: 'item1' }));
        expect(component.find('a').prop('aria-current')).toBe('page');
    });
    it('should pass the iconName passed to the Icon component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { label: 'item 1', name: 'item1', iconName: 'utility:log_a_call' }));
        expect(component.find('Icon').prop('iconName')).toBe('utility:log_a_call');
    });
    it('should render the label passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { label: 'item label', name: 'item1' }));
        expect(component.find('a').text()).toBe('item label');
    });
    it('should pass the notification passed to the Notification component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { label: 'item 1', name: 'item1', notification: '23' }));
        expect(component.find('Notification').prop('notification')).toBe('23');
    });
    it('should fire an event onClick when the item is clicked', function () {
        var onClickMockFn = jest.fn();
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { label: 'item 1', name: 'item35', onClick: onClickMockFn, onSelect: function onSelect() {} }));
        component.find('li').simulate('click');
        expect(onClickMockFn).toHaveBeenCalledWith(expect.any(Object));
    });
    it('should fire an event onSelect when the item is clicked', function () {
        var onSelectMockFn = jest.fn();
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { label: 'item 1', name: 'item35', onSelect: onSelectMockFn }));
        component.find('li').simulate('click');
        expect(onSelectMockFn).toHaveBeenCalledWith(expect.any(Object), 'item35');
    });
});