'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /* eslint-disable no-script-url, react/prop-types */


exports.default = VerticalItem;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _iconNamePropType = require('./../../propTypes/iconNamePropType');

var _iconNamePropType2 = _interopRequireDefault(_iconNamePropType);

var _icon = require('./icon');

var _icon2 = _interopRequireDefault(_icon);

var _notification = require('./notification');

var _notification2 = _interopRequireDefault(_notification);

var _context = require('../VerticalNavigation/context');

var _context2 = require('../VerticalSection/context');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Item(props) {
    var label = props.label,
        iconName = props.iconName,
        name = props.name,
        href = props.href,
        onClick = props.onClick,
        notification = props.notification,
        className = props.className,
        style = props.style,
        selectedItem = props.selectedItem,
        onSelect = props.onSelect,
        entityHeaderId = props.entityHeaderId;

    var isSelected = name === selectedItem;

    var getContainerClassNames = function getContainerClassNames() {
        return (0, _classnames2.default)('slds-nav-vertical__item', {
            'slds-is-active': isSelected
        }, className);
    };

    var getAriaCurrent = function getAriaCurrent() {
        if (isSelected) {
            return 'page';
        }
        return undefined;
    };

    function hanldeOnClick(e) {
        onClick(e);
        onSelect(e, name);
    }

    return _react2.default.createElement(
        'li',
        { className: getContainerClassNames(), style: style, role: 'presentation', onClick: hanldeOnClick },
        _react2.default.createElement(
            'a',
            {
                href: href,
                'aria-describedby': entityHeaderId,
                className: 'slds-nav-vertical__action',
                'aria-current': getAriaCurrent() },
            _react2.default.createElement(_icon2.default, { iconName: iconName }),
            label,
            _react2.default.createElement(_notification2.default, { notification: notification })
        )
    );
}

/**
* A text-only link within VerticalNavigationSection or VerticalNavigationOverflow.
*/
function VerticalItem(props) {
    return _react2.default.createElement(
        _context.Consumer,
        null,
        function (context) {
            return _react2.default.createElement(
                _context2.Consumer,
                null,
                function (entityHeaderId) {
                    return _react2.default.createElement(Item, _extends({}, props, context, { entityHeaderId: entityHeaderId }));
                }
            );
        }
    );
}

VerticalItem.propTypes = {
    /** The text displayed for the navigation item. */
    label: _propTypes2.default.string,
    /** A unique identifier for the navigation item. */
    name: _propTypes2.default.string.isRequired,
    /** The Lightning Design System name of the icon used as a fallback when
     * the image fails to load. Names are written in the format {sprite_name}:{icon_name}
     * where {sprite_name} is the category, and {icon_name} is the specific icon to be displayed.
     * Only utility icons can be used in this component. */
    iconName: _iconNamePropType2.default.oneOf(['utility']),
    /** The URL of the page that the navigation item goes to. */
    href: _propTypes2.default.string,
    /** The notification comoponent to display on the right. */
    notification: _propTypes2.default.node,
    /** Event fired when the item is clicked. */
    onClick: _propTypes2.default.func,
    /** A CSS class for the outer element, in addition to the component's base classes. */
    className: _propTypes2.default.string,
    /** An object with custom style applied for the outer element. */
    style: _propTypes2.default.object
};

VerticalItem.defaultProps = {
    label: '',
    iconName: undefined,
    href: 'javascript:void(0);',
    onClick: function onClick() {},
    notification: null,
    className: undefined,
    style: undefined
};