'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _reactTestRenderer = require('react-test-renderer');

var _reactTestRenderer2 = _interopRequireDefault(_reactTestRenderer);

var _ = require('./../');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<VerticalSectionOverflow/>', function () {
    it('should change the isExpanded state when the button element is clicked', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        expect(component.state().isExpanded).toBe(false);
        component.find('button').simulate('click');
        expect(component.state().isExpanded).toBe(true);
    });
    it('should change the isExpanded state when the button element is clicked and the expanded is set to true', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { expanded: true }));
        expect(component.state().isExpanded).toBe(true);
        component.find('button').simulate('click');
        expect(component.state().isExpanded).toBe(false);
    });
    it('should set a generated id as aria-controls in button element and as id in the overflow container', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        expect(component.find('button').prop('aria-controls')).toMatch(/search-results/);
        expect(component.find('div[data-id="vertical-overflow"]').prop('id')).toMatch(/search-results/);
    });
    it('should set the aria-expanded in the button element to false initially', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        expect(component.find('button').prop('aria-expanded')).toBe(false);
    });
    it('should set the aria-expanded in the button element to true if expanded is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { expanded: true }));
        expect(component.find('button').prop('aria-expanded')).toBe(true);
    });
    it('should set the aria-expanded in the button element to true if it is clicked', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        expect(component.find('button').prop('aria-expanded')).toBe(false);
        component.find('button').simulate('click');
        expect(component.find('button').prop('aria-expanded')).toBe(true);
    });
    it('should pass the right props to the IconSvg component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        expect(component.find('IconSvg').props()).toEqual({
            iconName: 'utility:chevronright',
            className: 'slds-button__icon slds-button__icon_left'
        });
    });
    it('should pass the right props to Label component when use default values', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        expect(component.find('Label').props()).toEqual({
            collapsedLabel: 'Show More',
            expandedLabel: 'Show Less',
            isExpanded: false
        });
    });
    it('should pass the right props to Label component when the respective props are passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { collapsedLabel: 'collapsed label', expandedLabel: 'expanded label', expanded: true }));
        expect(component.find('Label').props()).toEqual({
            collapsedLabel: 'collapsed label',
            expandedLabel: 'expanded label',
            isExpanded: true
        });
    });
    it('should set the isExpanded prop in Label component to true when the the button is clicked', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        expect(component.find('Label').prop('isExpanded')).toBe(false);
        component.find('button').simulate('click');
        expect(component.find('Label').prop('isExpanded')).toBe(true);
    });
    it('should set the assistiveText passed as text in AssistiveText component', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { assistiveText: 'description text' }));
        expect(component.find('AssistiveText').prop('text')).toBe('description text');
    });
    it('should set the right className in the overflow container when is closed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        expect(component.find('div[data-id="vertical-overflow"]').prop('className')).toBe('slds-hide');
    });
    it('should set the right className in the overflow container when expanded is passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { expanded: true }));
        expect(component.find('div[data-id="vertical-overflow"]').prop('className')).toBe('slds-show');
    });
    it('should set the right className in the overflow container when the button is clicked', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(_2.default, null));
        expect(component.find('div[data-id="vertical-overflow"]').prop('className')).toBe('slds-hide');
        component.find('button').simulate('click');
        expect(component.find('div[data-id="vertical-overflow"]').prop('className')).toBe('slds-show');
    });
    it('should render the children passed', function () {
        var component = (0, _enzyme.mount)(_react2.default.createElement(
            _2.default,
            null,
            _react2.default.createElement(
                'span',
                null,
                'the section children'
            )
        ));
        expect(component.find('ul').text()).toBe('the section children');
    });
    it('should have the right class names when a custom className is passed', function () {
        var component = _reactTestRenderer2.default.create(_react2.default.createElement(_2.default, { className: 'custom-class-name' }));
        expect(component).toMatchSnapshot();
    });
});