'use strict';

var _iconNamePropTypeValidator = require('../iconNamePropTypeValidator');

var _iconNamePropTypeValidator2 = _interopRequireDefault(_iconNamePropTypeValidator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var propName = 'iconName';
var componentName = 'TestComponent';
var error = new Error('Invalid prop `' + propName + '` supplied to `' + componentName + '`, expected a string in the format of {sprite}:{icon_name}, where sprite is one of [ action,custom,doctype,standard,utility ].');
var customPrefixesError = new Error('Invalid prop `' + propName + '` supplied to `' + componentName + '`, expected a string in the format of {sprite}:{icon_name}, where sprite is one of [ utility,action,standard ].');

describe('iconNamePropTypeValidator function', function () {
    it('should return an error if the icon name does`nt contain :', function () {
        var props = { iconName: 'utility' };
        var result = (0, _iconNamePropTypeValidator2.default)(undefined, props, propName, componentName);
        expect(result).toEqual(error);
    });
    it('should return an error if the icon name category is not valid', function () {
        var props = { iconName: 'fail:world' };
        var result = (0, _iconNamePropTypeValidator2.default)(undefined, props, propName, componentName);
        expect(result).toEqual(error);
    });
    it('should return an error if the icon name category is not valid when icons categories are specified', function () {
        var props = { iconName: 'fail:world' };
        var result = (0, _iconNamePropTypeValidator2.default)(['utility', 'action', 'standard'], props, propName, componentName);
        expect(result).toEqual(customPrefixesError);
    });
    it('should return null if the icon name is valid', function () {
        var props = { iconName: 'utility:world' };
        var result = (0, _iconNamePropTypeValidator2.default)(undefined, props, propName, componentName);
        expect(result).toBeNull();
    });
    it('should return null if the icon name is valid when icons categories are specified', function () {
        var props = { iconName: 'utility:world' };
        var result = (0, _iconNamePropTypeValidator2.default)(['utility', 'action', 'standard'], props, propName, componentName);
        expect(result).toBeNull();
    });
});